# CalCalc

Welcome to the coolest calculator you have ever used in python! Ask it any question your heart desires. Start small with simple math, but feel free to branch out and ask it more difficult questions. You might be wondering what the mass of the moon is, or what the average life expectancy of people in Germany is, or maybe you might be wondering... what is the meaning of life? These can all be answered by CalCalc! 

### Basic Usage:

```python
import calcalc.CalCalc as cal

cal.calculate("7 * 4")
28

cal.calculate("abs(-10)")
10

cal.calculate("what is the mass of the moon in kg")
"7.3459×10^22 kg (kilograms)"
```
